@@ -328,7 +328,7 @@ class RosdepLookup(object):
     @staticmethod
     def create_from_rospkg(rospack=None, rosstack=None,
                            sources_loader=None,
-                           verbose=False):
+                           verbose=False, dependency_types=None):
         """
         Create :class:`RosdepLookup` based on current ROS package
         environment.
@@ -339,6 +339,8 @@ class RosdepLookup(object):
           instance used to crawl ROS stacks.
         :param sources_loader: (optional) Override SourcesLoader used
             for managing sources.list data sources.
+        :param dependency_types: (optional) List of dependency types.
+            Allowed: {'build', 'buildtool', 'build_export', 'buildtool_export', 'exec', 'test', 'doc'}
         """
         # initialize the loader
         if rospack is None:
@@ -347,6 +349,8 @@ class RosdepLookup(object):
             rosstack = RosStack()
         if sources_loader is None:
             sources_loader = SourcesListLoader.create_default(verbose=verbose)
+        if dependency_types is None:
+            dependency_types = []
 
         rosdep_db = RosdepDatabase()
 
@@ -358,7 +362,7 @@ class RosdepLookup(object):
 
         # Create the rospkg loader on top of the underlay
         loader = RosPkgLoader(rospack=rospack, rosstack=rosstack,
-                              underlay_key=underlay_key)
+                              underlay_key=underlay_key, dependency_types=dependency_types)
 
         # create our actual instance
         lookup = RosdepLookup(rosdep_db, loader)
