@@ -38,7 +38,7 @@ except ImportError:
 import rospkg.distro
 import rosdep2.sources_list
 
-GITHUB_BASE_URL = 'https://raw.github.com/ros/rosdistro/master/rosdep/base.yaml'
+GITHUB_BASE_URL = 'https://raw.githubusercontent.com/ros/rosdistro/master/rosdep/base.yaml'
 
 
 def get_test_dir():
@@ -324,7 +324,7 @@ def test_download_rosdep_data():
 BADHOSTNAME_URL = 'https://badhostname.willowgarage.com/rosdep.yaml'
 GITHUB_URL = 'https://github.com/ros/rosdistro/raw/master/rosdep/base.yaml'
 GITHUB_PYTHON_URL = 'https://github.com/ros/rosdistro/raw/master/rosdep/python.yaml'
-GITHUB_FUERTE_URL = 'https://raw.github.com/ros-infrastructure/rosdep_rules/master/rosdep_fuerte.yaml'
+GITHUB_FUERTE_URL = 'https://raw.githubusercontent.com/ros-infrastructure/rosdep_rules/master/rosdep_fuerte.yaml'
 EXAMPLE_SOURCES_DATA_BAD_TYPE = 'YAML %s' % (GITHUB_URL)
 EXAMPLE_SOURCES_DATA_BAD_URL = 'yaml not-a-url tag1 tag2'
 EXAMPLE_SOURCES_DATA_BAD_LEN = 'yaml'
@@ -484,3 +484,15 @@ def test_SourcesListLoader_create_default():
 
     #  - coverage, repeat loader, should noop
     loader.load_view(GITHUB_URL, rosdep_db)
+
+
+def test_unpickle_same_results():
+    try:
+        import cPickle as pickle
+    except ImportError:
+        import pickle
+    with open(os.path.join('test', 'fixtures', 'python2cache.pickle'), 'rb') as py2_cache:
+        py2_result = pickle.loads(py2_cache.read())
+    with open(os.path.join('test', 'fixtures', 'python3cache.pickle'), 'rb') as py3_cache:
+        py3_result = pickle.loads(py3_cache.read())
+    assert py2_result == py3_result
